@@ -4,9 +4,9 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,19 +20,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
-
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 #include "gchempaint-config.h"
 #include "application.h"
 #include "document.h"
@@ -41,6 +42,7 @@
 #include "plugin.h"
 #include "filechooser.h"
 #include "mendeleiev.h"
+#include "mesomer.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
 #include "reaction.h"
@@ -51,16 +53,15 @@
 #include <sys/stat.h>
 #include <gconf/gconf-client.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
-
-enum gcpFileTypes
-{
-	gcp_ft_Normal = 1,
-	gcp_ft_CML,
-	gcp_ft_SDF,
-	gcp_ft_PDB,
-	gcp_ft_ChemDraw,
-	gcp_ft_max
-};
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <locale.h>
+#ifdef HAS_OPENBABEL_2
+#	include <mol.h>
+#	include <obconversion.h>
+#else
+#	include <sstream>
+#endif
 
 // Objects creation static methods
 static Object* CreateMolecule()
@@ -98,6 +99,11 @@ static Object* CreateMesomeryArrow()
 	return new gcpMesomeryArrow(NULL);
 }
 
+static Object* CreateMesomer ()
+{
+	return new gcpMesomer ();
+}
+
 static Object* CreateText()
 {
 	return new gcpText();
@@ -110,14 +116,9 @@ static Object* CreateFragment()
 
 list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
-bool	gcpApplication::m_Have_ps2eps = false;
 bool	gcpApplication::m_Have_Ghemical = false;
 map<string, string> gcpApplication::m_SupportedPixbufFormats;
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchempaint-unstable" 
-
 gcpApplication::gcpApplication ()
 {
 	Apps.push_back(this);
@@ -126,6 +127,7 @@ gcpApplication::gcpApplication ()
 	m_pActiveTool = NULL;
 	m_pNode = NULL;
 	FontName = g_strdup("Bitstream Vera Serif 12");
+	CurDir = g_get_current_dir ();
 	GConfClient* cli = gconf_client_get_default ();
 	if (cli) {
 		const char *value;
@@ -174,19 +176,16 @@ gcpApplication::gcpApplication ()
 
 	if (!m_bInit) {
 		// Check for programs
-		char *result = NULL;;
-		// check for ps2eps
-		m_Have_ps2eps = (g_spawn_command_line_sync ("which ps2eps", &result, NULL, NULL, NULL)
-			&& result && strlen (result));
-		if (result) {
-			g_free (result);
-			result = NULL;
-		}
+		char *result = NULL, *errors = NULL;
 		// check for ghemical
-		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, NULL, NULL, NULL)
+		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
 		if (result)
 			g_free (result);
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
 		// check supported pixbuf formats
 		GSList *formats = gdk_pixbuf_get_formats ();
 		GSList *l = formats;
@@ -213,6 +212,7 @@ gcpApplication::gcpApplication ()
 		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
 		Object::AddType ("reactant", CreateReactant, ReactantType);
 		Object::AddType("reaction-arrow", CreateReactionArrow, ReactionArrowType);
+		MesomerType = Object::AddType ("mesomer", CreateMesomer);
 		Object::AddType ("mesomery", CreateMesomery, MesomeryType);
 		Object::SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
 		Object::AddType("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
@@ -227,7 +227,9 @@ gcpApplication::gcpApplication ()
 		Object::AddRule ("reaction", RuleMustContain, "reaction-arrow");
 		Object::AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
 		Object::AddRule ("reactant", RuleMayContain, "molecule");
-		Object::AddRule ("mesomery", RuleMustContain, "molecule");
+		Object::AddRule ("mesomer", RuleMustContain, "molecule");
+		Object::AddRule ("mesomer", RuleMustBeIn, "mesomery");
+		Object::AddRule ("mesomery", RuleMustContain, "mesomer");
 		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
 		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
 
@@ -342,6 +344,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 	{
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Please enter a file name,\nnot a directory"));
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 		return true;
@@ -358,13 +361,19 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			if (!strcmp(ext, ".gchempaint")) filetype = gcp_ft_Normal;
 			else if (!strcmp(ext, ".cml")) filetype = gcp_ft_CML;
 			else if (!strcmp(ext, ".mol")) filetype = gcp_ft_SDF;
-			else if (!strcmp(ext, ".mdl")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".sdf")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".sd")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".pdb")) filetype = gcp_ft_PDB;
 			else if (!strcmp(ext, ".ent")) filetype = gcp_ft_PDB;
 			else if (!strcmp(ext, ".chm")) filetype = gcp_ft_ChemDraw;
-			else filetype = gcp_ft_Normal;
+			else {
+				GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+															_("Sorry, format not supported!"));
+				gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
+				gtk_dialog_run (GTK_DIALOG (message));
+				gtk_widget_destroy (message);
+				return true;
+			}
 		}
 		else filetype = gcp_ft_Normal;
 	}
@@ -374,8 +383,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			case gcp_ft_Normal: ext = ".gchempaint"; break;
 			case gcp_ft_CML: ext = ".cml"; break;
 			case gcp_ft_SDF:
-				if (!strcmp(filename + n - 3, "mdl")) ext = ".mdl";
-				else if (!strcmp(filename + n - 3, "sdf")) ext = ".sdf";
+				if (!strcmp(filename + n - 3, "sdf")) ext = ".sdf";
 				else if (!strcmp(filename + n - 2, "sd")) ext = ".sd";
 				else if (bSave) ext = ".mol";
 				break;
@@ -390,7 +398,8 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		}
 	gchar* filename2;
 	struct stat buf;
-	gint err;
+	bool err;
+	GnomeVFSURI *uri;
 	if (bSave)
 	{
 		if (ext)
@@ -402,18 +411,28 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				filename2 = g_strdup_printf("%s%s", filename, ext);
 		}
 		else filename2 = g_strdup(filename);
-		err = stat(filename2, &buf);
+		uri = gnome_vfs_uri_new (filename2);
+		err = gnome_vfs_uri_exists (uri);
+		gnome_vfs_uri_unref (uri);
 		gint result = GTK_RESPONSE_YES;
-		if (!err)
+		if (err)
 		{
 			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename2);
 			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run(Box);
 			gtk_widget_destroy(GTK_WIDGET(Box));
 			g_free(message);
 		}
 		if (result == GTK_RESPONSE_YES)
 		{
+#ifdef HAS_OPENBABEL_2
+			pDoc->SetType (filetype);
+			if (filetype == gcp_ft_Normal)
+				SaveGcp (filename2, pDoc);
+			else
+				SaveWithBabel (filename2, ext, pDoc, filetype);
+#else
 			switch(filetype)
 			{
 				case gcp_ft_Normal:
@@ -425,11 +444,14 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				case gcp_ft_PDB: SaveWithBabel(filename2, ext, pDoc, PDB); break;
 				case gcp_ft_ChemDraw: SaveWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
 			}
+#endif
 		}
 	}
 	else //loading
 	{
-		err = stat(filename, &buf);
+		uri = gnome_vfs_uri_new (filename);
+		err = !gnome_vfs_uri_exists (uri);
+		gnome_vfs_uri_unref (uri);
 		if (err)
 		{
 			if (!ext)
@@ -437,25 +459,42 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				{
 					case gcp_ft_SDF:
 						filename2 = g_strdup_printf("%s.%s",filename, "mol");
-						if (!stat(filename2, &buf)) break;
-						g_free(filename2);
-						filename2 = g_strdup_printf("%s.%s",filename, "mdl");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "sdf");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "sd");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup(filename);
 						break;
 					case gcp_ft_PDB:
 						filename2 = g_strdup_printf("%s.%s",filename, "pdb");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "ent");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup(filename);
 						break;
@@ -463,13 +502,22 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 						filename2 = g_strdup(filename);
 				}
 			else filename2 = g_strdup_printf("%s%s",filename, ext);
-			if (stat(filename2, &buf))
+			uri = gnome_vfs_uri_new (filename2);
+			err = !gnome_vfs_uri_exists (uri);
+			gnome_vfs_uri_unref (uri);
+			if (err)
 			{
 				g_free(filename2);
 				filename2 = g_strdup(filename);
 			}
 		}
 		else filename2 = g_strdup(filename);
+#ifdef HAS_OPENBABEL_2
+		if (filetype == gcp_ft_Normal)
+			OpenGcp (filename2, pDoc);
+		else
+			OpenWithBabel (filename2, ext, pDoc, filetype);
+#else
 		switch (filetype)
 		{
 			case gcp_ft_Normal: OpenGcp(filename2, pDoc); break;
@@ -478,6 +526,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			case gcp_ft_PDB: OpenWithBabel(filename2, ext, pDoc, PDB); break;
 			case gcp_ft_ChemDraw: OpenWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
 		}
+#endif
 	}
 	g_free(filename2);
 	return false;
@@ -493,23 +542,66 @@ void gcpApplication::SaveWithBabel(const gchar* filename, const gchar* ext, gcpD
 void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpDocument* pDoc, int Type)
 {
 	char *old_num_locale;
-	bool bNew = (pDoc == NULL);
+	bool bNew = (pDoc == NULL), local;
+	GnomeVFSFileInfo *info = NULL;
+	bool result;
 	try
 	{
 		if (!filename) throw (int) 0;
-		ifstream ifs;
-		ifs.open(filename);
-		if (!ifs) throw (int) 1;
-		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-		setlocale(LC_NUMERIC, "C");
-		OBMol Mol((io_type)Type);
-		OBFileFormat fileFormat;
-		fileFormat.ReadMolecule(ifs, Mol);
-		if (bNew) pDoc = new gcpDocument(this, true);
-		bool result = pDoc->ImportOB(Mol);
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
-		ifs.close();
+		info = gnome_vfs_file_info_new ();
+		gnome_vfs_get_file_info (filename, info, GNOME_VFS_FILE_INFO_DEFAULT);
+		local = GNOME_VFS_FILE_INFO_LOCAL (info);
+		gnome_vfs_file_info_unref (info);
+		if (bNew)
+			pDoc = new gcpDocument (this, true);
+		if (local) {
+			ifstream ifs;
+			GnomeVFSURI *uri = gnome_vfs_uri_new (filename);
+			ifs.open (gnome_vfs_uri_get_path (uri));
+			gnome_vfs_uri_unref (uri);
+			if (!ifs) throw (int) 1;
+			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+			setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+			OBMol Mol;
+			OBConversion Conv;
+			OBFormat* pInFormat = Conv.FormatFromExt (filename);
+			Conv.SetInAndOutFormats (pInFormat, pInFormat);
+			Conv.Read (&Mol, &ifs);
+#else
+			OBMol Mol ((io_type) Type);
+			OBFileFormat fileFormat;
+			fileFormat.ReadMolecule (ifs, Mol);
+#endif
+			result = pDoc->ImportOB(Mol);
+			setlocale (LC_NUMERIC, old_num_locale);
+			g_free (old_num_locale);
+			ifs.close ();
+		} else {
+			char *buf;
+			int size;
+			if (gnome_vfs_read_entire_file (filename, &size, &buf) != GNOME_VFS_OK)
+				throw 1;
+			istringstream iss (buf);
+			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+			setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+			OBMol Mol;
+			OBConversion Conv;
+			OBFormat* pInFormat = Conv.FormatFromExt (filename);
+			Conv.SetInAndOutFormats (pInFormat, pInFormat);
+			Conv.Read (&Mol, &iss);
+#else
+			OBMol Mol ((io_type) Type);
+			OBFileFormat fileFormat;
+			fileFormat.ReadMolecule (iss, Mol);
+#endif
+			result = pDoc->ImportOB(Mol);
+			setlocale (LC_NUMERIC, old_num_locale);
+			setlocale (LC_NUMERIC, old_num_locale);
+			g_free (old_num_locale);
+			g_free (buf);
+		}
 		if (!result)
 		{
 			if (bNew) delete pDoc;
@@ -536,6 +628,7 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
@@ -548,14 +641,39 @@ void gcpApplication::SaveGcp(const gchar* filename, gcpDocument* pDoc)
 	pDoc->Save();
 }
 
+static int	cb_vfs_to_xml (GnomeVFSHandle *handle, char* buf, int nb)
+{
+	GnomeVFSFileSize ndone;
+	return  (gnome_vfs_read (handle, buf, nb, &ndone) == GNOME_VFS_OK)? (int) ndone: -1;
+}
+
 void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 {
 	xmlDocPtr xml;
 	char *old_num_locale, *old_time_locale;
+	GnomeVFSFileInfo *info = NULL;
 	try
 	{
-		if (!filename) throw (int) 0;
-		if (!(xml = xmlParseFile(filename))) throw (int) 1;
+		if (!filename)
+			throw (int) 0;
+
+		// try opening with write access to see if it is readonly
+		// use xmlReadIO for non local files.
+		info = gnome_vfs_file_info_new ();
+		gnome_vfs_get_file_info (filename, info, GNOME_VFS_FILE_INFO_DEFAULT);
+
+		if (GNOME_VFS_FILE_INFO_LOCAL (info)) {
+			if (!(xml = xmlParseFile(filename)))
+				throw (int) 1;
+		} else {
+			GnomeVFSHandle *handle;
+			GnomeVFSResult result = gnome_vfs_open (&handle, filename, GNOME_VFS_OPEN_READ);
+			if (result != GNOME_VFS_OK)
+				throw 1;
+			if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
+					 (xmlInputCloseCallback) gnome_vfs_close, handle, filename, NULL, 0)))
+				throw 1;
+		}
 		if (xml->children == NULL) throw (int) 2;
 		if (strcmp((char*)xml->children->name, "chemistry")) throw (int) 3;	//FIXME: that could change when a dtd is available
 		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
@@ -575,10 +693,15 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 			throw (int) 4;
 		}
 		AddDocument(pDoc);
+		if (!(info->permissions & (GNOME_VFS_PERM_USER_WRITE | GNOME_VFS_PERM_GROUP_WRITE)))
+			pDoc->SetReadOnly (true);
+		gnome_vfs_file_info_unref (info);
 		xmlFreeDoc(xml);
 	}
 	catch (int num)
 	{
+		if (info)
+			gnome_vfs_file_info_unref (info);
 		if (num > 1) xmlFreeDoc(xml);
 		gchar *mess;
 		GtkWidget* message;
@@ -601,6 +724,7 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
@@ -704,14 +828,15 @@ void gcpApplication::OnSaveAsImage ()
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
 		gtk_file_filter_add_mime_type (filter, (*i).first.c_str ());
 	gtk_file_filter_add_mime_type (filter, "image/svg+xml");
-	if (m_Have_ps2eps)
-		gtk_file_filter_add_mime_type (filter, "image/x-eps");
+	gtk_file_filter_add_mime_type (filter, "image/x-eps");
+	gtk_file_filter_add_mime_type (filter, "image/x-xfig");
 	gtk_file_chooser_set_filter (dialog, filter);
 	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
 		filename = gtk_file_chooser_get_filename (dialog);
 		if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/') {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 																_("Please enter a file name,\nnot a directory"));
+			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			continue;
@@ -724,6 +849,7 @@ void gcpApplication::OnSaveAsImage ()
 		{
 			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename);
 			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run(Box);
 			gtk_widget_destroy(GTK_WIDGET(Box));
 			g_free(message);
@@ -733,22 +859,14 @@ void gcpApplication::OnSaveAsImage ()
 		const char* mime_type = gnome_vfs_mime_type_from_name (filename);
 		if (m_SupportedPixbufFormats.find (mime_type) != m_SupportedPixbufFormats.end())
 			m_pActiveDoc->ExportImage (filename, m_SupportedPixbufFormats[mime_type].c_str ());
-		else if (!strcmp (mime_type, "image/x-eps")) {
-			if (m_Have_ps2eps)
+		else if (!strcmp (mime_type, "image/x-eps"))
 				m_pActiveDoc->ExportImage (filename, "eps");
-			else {
-				GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-																	"Can't export eps files, please install ps2eps");
-				gtk_dialog_run (GTK_DIALOG (message));
-				gtk_widget_destroy (message);
-			}
-		}
 		else if (!strcmp (mime_type, "image/svg+xml")) {
 			m_pActiveDoc->ExportImage (filename, "svg");
-		}
-		else {
+		} else {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-																_("Sorry, format not supported !"));
+																_("Sorry, format not supported!"));
+			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			continue;
@@ -758,3 +876,10 @@ void gcpApplication::OnSaveAsImage ()
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 	return;	
 }
+
+void gcpApplication::SetCurDir (char const* dir)
+{
+	if (CurDir)
+		g_free (CurDir);
+	CurDir = g_strdup (dir);
+}
