@@ -79,7 +79,7 @@ public :
 	virtual void SetZ(int Z);
 	void AddBond(Bond* pBond);
 	void RemoveBond(Bond* pBond);
-	void Update();
+	virtual void Update();
 	virtual void Add(GtkWidget* w);
 	virtual void Update(GtkWidget* w);
 	int GetTotalBondsNumber(); //take bond order into account
@@ -108,6 +108,7 @@ public :
 	void NotifyPositionOccupation (unsigned char pos, bool occupied);
 	void SetChargePosition (unsigned char Pos, bool def, double angle = 0., double distance = 0.);
 	char GetChargePosition (double *Angle, double *Dist);
+	void SetCharge (int charge);
 
 private:
 	void BuildItems (gcpWidgetData* pData);
@@ -136,6 +137,7 @@ private:
 	bool m_ChargeAutoPos;
 	double m_ChargeAngle;
 	double m_ChargeDist;
+	double m_ChargeWidth, m_ChargeTWidth, m_ChargeXOffset, m_ChargeYOffset;
 	list<double> m_AngleList;
 	map<double, double> m_InterBonds; /* positions betwen bonds. First  value is the
 	angle between the two bonds and second value is the direction */
