@@ -403,25 +403,33 @@ bool gcpTextTool::DeleteSelection()
 	return true;
 }
 
-bool gcpTextTool::CopySelection(GtkClipboard *clipboard)
+bool gcpTextTool::CopySelection (GtkClipboard *clipboard)
 {
-	if (!m_Active) return false;
-	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer(m_Active);
+	if (!m_Active)
+		return false;
+	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer (m_Active);
 	GtkTextIter start, end;
-	gtk_text_buffer_get_selection_bounds(buf, &start, &end);
-	if (gtk_text_iter_equal(&start, &end)) return false; //Nothing to copy
-	m_pData->Copy(clipboard); //To clean the xmlDoc
-	xmlDocPtr pDoc = m_pData->GetXmlDoc(clipboard);
-	if (!pDoc) return false;
-	pDoc->children = xmlNewDocNode(pDoc, NULL, (xmlChar*)"chemistry", NULL);
-	gcpText *text = (gcpText*)g_object_get_data(G_OBJECT(m_Active), "object");
-	xmlNodePtr node = text->SaveSelection(pDoc);
-	if (node) xmlAddChild(pDoc->children, node);
-	else return false;
-	gtk_clipboard_set_with_data(clipboard, targets, 2,
-		(GtkClipboardGetFunc)on_get_data,
-		(GtkClipboardClearFunc)on_clear_data, NULL);
-	gtk_clipboard_request_contents(clipboard, gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc)on_receive_targets, NULL);
+	gtk_text_buffer_get_selection_bounds (buf, &start, &end);
+	if (gtk_text_iter_equal (&start, &end))
+		return false; //Nothing to copy
+	m_pData->Copy (clipboard); //To clean the xmlDoc
+	xmlDocPtr pDoc = m_pData->GetXmlDoc (clipboard);
+	if (!pDoc)
+		return false;
+	pDoc->children = xmlNewDocNode (pDoc, NULL, (xmlChar*) "chemistry", NULL);
+	gcpText *text = (gcpText*) g_object_get_data (G_OBJECT (m_Active), "object");
+	xmlNodePtr node = text->SaveSelection (pDoc);
+	if (node)
+		xmlAddChild (pDoc->children, node);
+	else
+		return false;
+	gtk_clipboard_set_with_data (clipboard, targets, 2,
+		(GtkClipboardGetFunc) on_get_data,
+		(GtkClipboardClearFunc) on_clear_data, this);
+	gtk_clipboard_request_contents (clipboard,
+			gdk_atom_intern ("TARGETS", FALSE),
+			(GtkClipboardReceivedFunc) on_receive_targets,
+			m_pApp);
 	return true;
 }
 
@@ -617,5 +625,5 @@ void gcpTextTool::OnGetData(GtkClipboard *clipboard, GtkSelectionData *selection
 		gtk_selection_data_set(selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8,  (const guchar*) ClipboardData, size);
 	}
 	cleared = false;
-	if (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD)) m_pApp->ActivateMenu("Paste", true);
+	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD)) m_pApp->ActivateMenu("Paste", true);
 }
